# -*- coding: utf-8 -*-

"""Tests dict input objects for `cookiecutter.prompt` module."""

import pytest
import yaml

from cookiecutter import prompt

FIXTURES = []


# @pytest.mark.parametrize("input_dicts,invalid", FIXTURES)
# def test_hook_checkbox(self, monkeypatch):
#     """Verify `prompt_for_config` call `read_user_variable` on dict request."""
#



# -*- coding: utf-8 -*-

"""Tests dict input objects for `cookiecutter.prompt` module."""

from cookiecutter.operator import run_operator, parse_operator

context = {
    'cookiecutter': {
        'project_name': "Slartibartfast",
        'details': {"type": "command", "command": "echo here"},
    }
}


def test_command():
    """Verify simplest functionality."""
    operator_output, delayed_output = run_operator(
        context['cookiecutter']['details'], context
    )
    assert operator_output == 'here\n'
    assert not delayed_output

    cookiecutter_dict = parse_operator(context, 'details', {})
    assert cookiecutter_dict == {'details': 'here\n'}



# # -*- coding: utf-8 -*-
#
# """Tests dict input objects for `cookiecutter.prompt` module."""
#
# from cookiecutter.operators.cookiecutter import NukikataOperator
# import os
#
# context = {
#     'cookiecutter': {
#         'project_name': "Slartibartfast",
#         'details': {"type": "cookiecutter",
#                     "template": "https://github.com/insight-infrastructure/cookiecutter-terraform-terratest-aws"},
#                     "no_input": True
#     }
# }
#
#
# def test_cookiecutter():
#     """Verify simplest functionality."""
#     c = NukikataOperator(context['cookiecutter']['details'], context)
#     d = c.execute()
#     assert d.rstrip() == os.path.abspath(os.path.dirname(__file__))
